---
layout: book
section: documentation
category: TileMill
tag: Crash&nbsp;course
title: "Styling data"
permalink: /docs/crashcourse/styling
prereq:
- "[Installed](/tilemill/docs/install) TileMill on your computer."
- "[Reviewed](/tilemill/docs/crashcourse/introduction/) the Crash Course introduction."
- "[Imported data](/tilemill/docs/crashcourse/point-data) into a TileMill project."
nextup:
- "[Adding tooltips and a legend](/tilemill/docs/crashcourse/tooltips/) to your map."
- "[Exporting](/tilemill/docs/crashcourse/exporting/) your map."
---

{% include prereq.html %}


TileMill uses a language called Carto to determine the look of a map. Colors, sizes, and shapes can all be manipulated by applying their relative Carto parameters in the stylesheet panel to the right of the map. Read the [Carto manual](/tilemill/docs/manual/carto/) for a more detailed introduction to the language.

In the previous crash course section on [Importing data](/tilemill/docs/crashcourse/point-data), we [added an earthquake point layer](/tilemill/docs/crashcourse/point-data) using the "Save & Style" button. This button automatically added several styling parameters to your stylesheet and gave them an initial value.
  ![Styling](/tilemill/assets/pages/styling-1.png)

1. `#earthquakes`  
This is the layer to which the styles are applied.

2. `marker-width`  
This determines the size of the markers, in pixels. If `marker-height` is not specified, it is given the same value, resulting in a circle marker. You can experiment with changing this by typing in a different number.

3. Click the "Save" button to save your project and trigger the map preview to update.
  ![Save project](/tilemill/assets/pages/save-project.png)

4. `marker-fill`  
This is the color of the inside of the marker. There are two methods for changing color values. You can either type in a new value, or you can use the color swatches at the bottom of the Carto panel. Try changing the marker color by clicking the light red swatch and selecting a new color.
  ![Styling](/tilemill/assets/pages/styling-3.png)

5. Click "Save" in the color picker to see your changes. Notice the corresponding color value is updated in the Carto.
  ![](/tilemill/assets/pages/color-picker-1.png)

6. `marker-line-color`  
This is the color of the border of the marker. This time try changing the color by replacing the hex value `#813` with `#000`, the code for black.

7. Click "Save". Notice that the color swatch is updated with the new color.

8. `marker-allow-overlap`  
This allows markers to be placed on top of each other. If this is not specified or set to `false`, potentially overlapping markers will not be displayed.

## Conditional styles

Conditional Carto styles allow you to change the appearance of the points on your map based on attributes in the data. Here we will customize the earthquake points based on the magnitude of the quake.

1. Review the available data for the layer in the feature inspector.
  ![Feature inspector](/tilemill/assets/pages/feature-inspector-1.png)
2. Find the column called `Magnitude` and examine the range of values. This will help you decide how to scale the points.
  ![Feature inspector](/tilemill/assets/pages/feature-inspector-2.png)
3. Add the following Carto rule to the bottom of your stylesheet. This Carto rule sets a larger `marker-width` for features that have a larger `Magnitude` value.

        #earthquakes {
          [Magnitude >= 2.5] { marker-width:6; }
          [Magnitude >= 3]   { marker-width:8; }
          [Magnitude >= 3.5] { marker-width:10; }
          [Magnitude >= 4]   { marker-width:12; }
          [Magnitude >= 4.5] { marker-width:14; }
          [Magnitude >= 5]   { marker-width:16; }
          [Magnitude >= 5.5] { marker-width:18; }
          [Magnitude >= 6]   { marker-width:20; }
        }

4. Click "Save" to view your changes.
5. Use the map preview to confirm that the style is working. Adjust the Carto rule until you are satisfied.
  ![Conditional style](/tilemill/assets/pages/conditional-style-1.png)

These are just a few of the basic parameters for styling point data. For a comprehensive look at styling possibilities, checkout the [Carto reference](/tilemill/docs/manual/carto/) section in TileMill.
  ![Styling](/tilemill/assets/pages/styling-4.png)

{% include nextup.html %}
